==> 0.0.31.tar.gz: lib/widgets/buy_courses.dart <==
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/princing_container.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter_firebase_basic_tools/models/payment_redirect_type.dart';
import 'package:shared_preferences/shared_preferences.dart';

class BuyCourses extends StatefulWidget {
  const BuyCourses({
    @required this.apiKey,
  });

  final String apiKey;

  @override
  _BuyCoursesState createState() => _BuyCoursesState();
}

class _BuyCoursesState extends State<BuyCourses> {
  final GlobalKey<FormState> loginFormKey = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();
  String currentLanguage = "en";
  CustomColors customColors = CustomColors();
  TranslationStream translationStream = TranslationStream();

  List<String> textList = [
    "Our courses",
    "Learn and get certified in any of them.",
    "White Belt",
    "\$100",
    "Yellow Belt",
    "\$249",
    "Black Belt",
    "\$300",
    "Buy now",
  ];

  SharedPreferences prefs;

  BuyerInfo args;

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();

    if (args.paymentRedirectType != PaymentRedirectType.none) {
      showAlertDialog(context, args.paymentRedirectType);
    }
  }

  showAlertDialog(
      BuildContext context, PaymentRedirectType paymentRedirectType) {
    showDialog(
      context: context,
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(
            paymentRedirectType == PaymentRedirectType.successful
                ? "Payment successful"
                : "Payment failed",
          ),
          actions: <Widget>[
            FlatButton(
              child: Text("Accept"),
              onPressed: () {
                Navigator.of(context).pop();
              },
            )
          ],
        );
      },
    );
  }

  updateTextList(int index, String newText) {
    textList[index] = newText;
    setState(() {});
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate(widget.apiKey);
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
    translationStream.init(textList, updateTextList);
    translationStream.translate(widget.apiKey);
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    args = ModalRoute.of(context).settings.arguments;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: true,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: customColors.green.withOpacity(0.7),
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: LanguagePicker(
                currentLanguage: currentLanguage,
                parentWidget: this,
                function: languagePickerCallback,
                itemsTextColor: CustomColors().oceanBlue,
                apiKey: widget.apiKey,
              ),
            ),
          ],
          customLeading: null,
        ),
      ),
      body: LayoutBuilder(
        builder: (BuildContext context, BoxConstraints viewportConstraints) {
          return SingleChildScrollView(
            scrollDirection: Axis.vertical,
            child: ConstrainedBox(
              constraints: BoxConstraints(
                minHeight: viewportConstraints.maxHeight,
              ),
              child: PricingContainer(
                texts: textList.sublist(0, 8),
                userID: args.userID,
                customerEmail: args.customerEmail,
                backgroundColor: Colors.blue.shade800,
                titleColor: Colors.white,
                subtitleColor: Colors.white,
                image1: 'assets/images/student_1.jpg',
                image2: 'assets/images/student_2.jpg',
                image3: 'assets/images/family.jpg',
              ),
            ),
          );
        },
      ),
    );
  }
}

class BuyerInfo {
  final String userID;
  final String customerEmail;
  final PaymentRedirectType paymentRedirectType;

  BuyerInfo({
    @required this.userID,
    @required this.customerEmail,
    @required this.paymentRedirectType,
  });
}

==> 0.0.126.tar.gz: lib/widgets/buy_courses.dart <==
import 'package:flutter_firebase_basic_tools/widgets/language_picker.dart';
import 'package:flutter_firebase_basic_tools/widgets/princing_container.dart';
import 'package:flutter_firebase_basic_tools/widgets/topbar.dart';
import 'package:flutter_firebase_basic_tools/logic/translate.dart';
import 'package:flutter_firebase_basic_tools/logic/custom_colors.dart';
import 'package:flutter/material.dart';
import 'package:flutter/widgets.dart';
import 'package:shared_preferences/shared_preferences.dart';

class BuyCourses extends StatefulWidget {
  const BuyCourses({
    @required this.itemsTextColor,
    @required this.languagePicker,
    @required this.buyerInfo,
    @required this.openPaymentViewFunction,
  });

  final Color itemsTextColor;
  final bool languagePicker;
  final BuyerInfo buyerInfo;
  final Function openPaymentViewFunction;

  @override
  _BuyCoursesState createState() => _BuyCoursesState();
}

class _BuyCoursesState extends State<BuyCourses> {
  final GlobalKey<FormState> loginFormKey = GlobalKey<FormState>();
  final GlobalKey<ScaffoldState> scaffoldKey = new GlobalKey<ScaffoldState>();
  String currentLanguage = "en";
  CustomColors customColors = CustomColors();
  TranslationStream translationStream = TranslationStream();

  List<String> textList = [
    "Our courses",
    "Learn and get certified in any of them.",
    "White Belt",
    "\$100",
    "Yellow Belt",
    "\$249",
    "Black Belt",
    "\$300",
    "Buy now",
  ];

  SharedPreferences prefs;

  initSharedPreferences() async {
    prefs = await SharedPreferences.getInstance();
  }

  updateTextList(int index, String newText) {
    textList[index] = newText;
    setState(() {});
  }

  languagePickerCallback(String newCurrentLanguage) async {
    currentLanguage = newCurrentLanguage;
    translationStream.translate();
    setState(() {});
  }

  @override
  void initState() {
    super.initState();
    initSharedPreferences();
    translationStream.init(textList, updateTextList);
    translationStream.translate();
  }

  @override
  Widget build(BuildContext context) {
    bool isLandscape =
        (MediaQuery.of(context).orientation == Orientation.landscape);

    double appBarSize = 65;

    return Scaffold(
      key: scaffoldKey,
      extendBodyBehindAppBar: true,
      appBar: PreferredSize(
        preferredSize: Size.fromHeight(appBarSize),
        child: Topbar(
          backgroundColor: customColors.green.withOpacity(0.7),
          size: appBarSize,
          hasBackButton: true,
          actions: <Widget>[
            Container(
              margin: EdgeInsets.only(right: 20),
              width: isLandscape ? 200 : 100,
              child: widget.languagePicker
                  ? LanguagePicker(
                      currentLanguage: currentLanguage,
                      parentWidget: this,
                      function: languagePickerCallback,
                      itemsTextColor: widget.itemsTextColor,
                    )
                  : Container(),
            ),
          ],
          customLeading: null,
          logoImage: "assets/images/abei_logo.png",
        ),
      ),
      body: LayoutBuilder(
        builder: (BuildContext context, BoxConstraints viewportConstraints) {
          return SingleChildScrollView(
            scrollDirection: Axis.vertical,
            child: ConstrainedBox(
              constraints: BoxConstraints(
                minHeight: viewportConstraints.maxHeight,
              ),
              child: PricingContainer(
                texts: textList.sublist(0, 8),
                userID: widget.buyerInfo.userID,
                customerEmail: widget.buyerInfo.customerEmail,
                backgroundColor: Colors.blue.shade800,
                titleColor: Colors.white,
                subtitleColor: Colors.white,
                image1: 'assets/images/student_1.jpg',
                image2: 'assets/images/student_2.jpg',
                image3: 'assets/images/family.jpg',
                openPaymentViewFunction: widget.openPaymentViewFunction,
              ),
            ),
          );
        },
      ),
    );
  }
}

class BuyerInfo {
  final String userID;
  final String customerEmail;

  BuyerInfo({
    @required this.userID,
    @required this.customerEmail,
  });
}
